====================================================
WFacer main functionalities
====================================================

This module contains major functionalities to construct cluster expansion
jobs and workflows in **WFacer**.

.. toctree::
   :maxdepth: 1

   convergence
   enumeration
   fit
   jobs
   maker
   preprocessing
   schema
   wrangling
